"use client";
import React, { useEffect, useMemo, useState } from "react";
import { useRouter } from "next/navigation";
// Chakra imports
import {
  Box,
  Button,
  Flex,
  FormControl,
  Heading,
  Text,
  useColorModeValue,
} from "@chakra-ui/react";

// Custom components
import DefaultAuthLayout from "@/layouts/auth/Default";
import Form from "@/components/form/Form";

// Assets
import Link from "next/link";
import prepareValidationSchema, { FormObject } from "@/utils/validation-schema";
import { InputWrapper, PasswordWrapper } from "@/components/fields/Fields";
import { ResetPassword } from "@/app/lib/actions/auth.actions";
import useShowToast from "@/app/hooks/useShowToast";

const formFields: FormObject[] = [
  {
    name: "password",
    label: "Password",
    type: "password",
    placeholder: "Min. 8 characters",
    required: true,
  },
  {
    name: "confirm_password",
    label: "Confirm Password",
    type: "password",
    placeholder: "Min. 8 characters",
    required: true,
  },
];

export default function SignUpPage() {
  // Chakra color mode
  const showToast = useShowToast();
  const router = useRouter();
  const textColor = useColorModeValue("navy.700.700", "white");
  const textColorSecondary = "gray.400";
  const textColorDetails = useColorModeValue("navy.700", "secondaryGray.600");
  const textColorBrand = useColorModeValue("brand.500", "white");
  const [signForm, setSignForm] = useState({});
  const [loading, setLoading] = useState(false);
  const [formValidationSchema, setFormValidationSchema] = useState({});
  const formDetails = useMemo(() => prepareValidationSchema(formFields), []);
  // Destructure formDetails
  const { initialFormData, validationSchema } = formDetails;

  useEffect(() => {
    setSignForm(initialFormData);
    setFormValidationSchema(validationSchema);
  }, [initialFormData, validationSchema]);

  const handleSubmit = async (values: { password: string, confirm_password: string }) => {
    setLoading(true);
    try {
      await ResetPassword({...values, reset_token: localStorage.getItem('reset_token')});
      showToast("Reset successful!", "Your password has been reset.", "success");
      localStorage.removeItem('reset_token');
      router.push('/auth/signin');
    } catch (error: any) {
      showToast("Reset failed", error.message, "error");
    }
    finally {
    setLoading(false);
    }
  };  

  return (
    <DefaultAuthLayout illustrationBackground={"/img/auth/medianet_logo.png"} >
      <Flex
        maxW={{ base: "100%", md: "max-content" }}
        w="100%"
        mx={{ base: "auto", lg: "0px" }}
        me="auto"
        h="100%"
        alignItems="start"
        justifyContent="center"
        mb={{ base: "30px", md: "0px" }}
        px={{ base: "25px", md: "0px" }}
        mt={{ base: "1vh", md: "3vh" }}
        flexDirection="column"
      >
        <Box me="auto">
          <Heading color={textColor} fontSize="36px" mb="10px">
            Reset Password
          </Heading>
          <Text
            mb="36px"
            ms="4px"
            w={{ base: "100%", md: "420px" }}
            color={textColorSecondary}
            fontWeight="400"
            fontSize="md"
          >
            Enter your email to reset your password!
          </Text>
        </Box>
        <Flex
          zIndex="2"
          direction="column"
          w={{ base: "100%", md: "100%" }}
          maxW="100%"
          background="transparent"
          borderRadius="15px"
          mx={{ base: "auto", lg: "unset" }}
          me="auto"
          mb={{ base: "20px", md: "auto" }}
        >
          <Form
            validationSchema={formValidationSchema}
            initialValues={signForm}
            submitForm={(formValues, formData) => {
              handleSubmit(formValues);
            }}
          >
            <FormControl w="full">
              {formFields.map((field) =>
                field.type === "password" ? (
                  <PasswordWrapper
                    key={field.name}
                    label={field.label}
                    form={true}
                    fieldName={field.name}
                    id={field.name}
                    placeholder={field.placeholder}
                    variant="auth"
                    w="full"
                    mb="2px"
                    fontSize="sm"
                    ms={{ base: "0px", md: "0px" }}
                    fontWeight="500"
                    size="lg"
                  />
                ) : (
                  <InputWrapper
                    key={field.name}
                    form={true}
                    fieldName={field.name}
                    id={field.name}
                    placeholder={field.placeholder}
                    variant="auth"
                    w="full"
                    mb="2px"
                    fontSize="sm"
                    ms={{ base: "0px", md: "0px" }}
                    type={field.type}
                    fontWeight="500"
                    size="lg"
                    label={field.label}
                    extra="*"
                  />
                )
              )}
              <Button
                type="submit"
                fontSize="sm"
                variant="brand"
                fontWeight="500"
                w="100%"
                h="50"
                mb="24px"
                isLoading={loading}
                loadingText="Submitting..."
                isDisabled={loading}>
                Submit
              </Button>
            </FormControl>
          </Form>
          <Flex
            flexDirection="column"
            justifyContent="center"
            alignItems="start"
            maxW="100%"
            mt="0px"
          >
            <Link href="/auth/signin">
              <Text color={textColorDetails} fontWeight="400" fontSize="14px">
                Already have an account?
                <Text
                  color={textColorBrand}
                  as="span"
                  ms="5px"
                  fontWeight="500"
                >
                  Sign in
                </Text>
              </Text>
            </Link>
          </Flex>
        </Flex>
      </Flex>
    </DefaultAuthLayout>
  );
}
